@@ -499,38 +499,38 @@ function remove_plugin($plugin_name)
   *                determined.
   *
   */
-function get_current_hook_name($args)
+function get_current_hook_name($args='')
 {
 
    if (check_sm_version(1, 5, 1))
    {
       global $currentHookName;
-      return $currentHookName;
+      if (!empty($currentHookName))
+         return $currentHookName;
    }
+
+
+//TODO: should we ALWAYS backtrace instead of assuming that $args[0] is the hook name?
+   if (!empty($args[0]) && is_string($args[0]))
+      return $args[0];
    else
    {
-//TODO: should we ALWAYS backtrace instead of assuming that $args[0] is the hook name?
-      if (!empty($args[0]) && is_string($args[0]))
-         return $args[0];
-      else
-      {
 
-         // plugin args not given or didn't have a hook
-         // name in them, so try backtracing instead
-         //
-         $backtrace = debug_backtrace();
-         foreach ($backtrace as $trace)
-            if ($trace['function'] == 'do_hook'
-             || $trace['function'] == 'do_hook_function'
-             || $trace['function'] == 'concat_hook_function'
-             || $trace['function'] == 'boolean_hook_function')
-               return $trace['args'][0];
+      // plugin args not given or didn't have a hook
+      // name in them, so try backtracing instead
+      //
+      $backtrace = debug_backtrace();
+      foreach ($backtrace as $trace)
+         if ($trace['function'] == 'do_hook'
+          || $trace['function'] == 'do_hook_function'
+          || $trace['function'] == 'concat_hook_function'
+          || $trace['function'] == 'boolean_hook_function')
+            return $trace['args'][0];
 
-         // nothing found at all
-         //
-         return '';
+      // nothing found at all
+      //
+      return '';
 
-      }
    }
 
 }
