@@ -21,199 +21,6 @@ function sq_new_function()
 
 
 
-//
-// taken from functions/global.php on 2007/06/23
-// since 1.5.2
-//
-if (!function_exists('sq_popen'))
-{
-function sq_popen($command, $mode) {
-
-    $mode = strtolower($mode{0});
-
-
-    if (!function_exists('proc_open'))
-        return popen($command, $mode);
-
-
-    // set up our process store if not done already
-    //
-    global $processes;
-    if (empty($processes))
-        $processes = array();
-
-
-    // define read, write and error pipes
-    //
-    $descriptors = array(0 => array('pipe', 'r'), 
-                         1 => array('pipe', 'w'), 
-                         2 => array('pipe', 'w'));
-
-
-    // start the child process
-    //
-    $proc = proc_open($command, $descriptors, $pipes);
-    if (!is_resource($proc)) 
-        return FALSE;
-
-
-    // when in read mode, we'll return a handle to the child's write pipe
-    //
-    if ($mode == 'r')
-        $return_value = $pipes[1];
-    else if ($mode == 'w')
-        $return_value = $pipes[0];
-    else 
-        die('sq_popen() expects $mode to be "r" or "w"');
-
-
-    // store the handle to the process and its pipes
-    // internally, keyed by whatever handle we'll be
-    // returning
-    //
-    $processes[$return_value] = array($proc, $pipes);
-
-
-    return $return_value;
-
-}
-}
-
-
-
-//
-// taken from functions/global.php on 2007/06/23
-// since 1.5.2
-//
-if (!function_exists('sq_get_pipe_stderr'))
-{
-function sq_get_pipe_stderr($handle, $timeout_seconds=0, $quiet=TRUE) {
-
-    // yes, we are testing for proc_OPEN 
-    // because we need to know how the 
-    // handle was actually OPENED
-    //
-    if (!function_exists('proc_open'))
-        return '';
-
-
-    // get our process out of the process store
-    //
-    global $processes;
-    if (!is_array($processes) || !isset($processes[$handle])) {
-        if (!quiet) {
-            plain_error_message(_("Failed to find corresponding open process handle"));
-        }
-        return '';
-    }
-    $proc = $processes[$handle];
-
-
-    // get all we can from stderr, don't wait longer 
-    // than our timeout for input
-    //
-    $contents = '';
-    $read = array($proc[1][2]);
-    $write = NULL;
-    $except = NULL;
-    if (stream_select($read, $write, $except, $timeout_seconds))
-        while (!feof($proc[1][2])) $contents .= fread($proc[1][2], 8192);
-    return $contents;
-
-}
-}
-
-
-
-//
-// taken from functions/global.php on 2007/06/23
-// since 1.5.2
-//
-if (!function_exists('sq_get_pipe_stdout'))
-{
-function sq_get_pipe_stdout($handle, $timeout_seconds=0, $quiet=TRUE) {
-
-    // yes, we are testing for proc_OPEN
-    // because we need to know how the
-    // handle was actually OPENED
-    //
-    if (!function_exists('proc_open'))
-        return '';
-
-
-    // get our process out of the process store
-    //
-    global $processes;
-    if (!is_array($processes) || !isset($processes[$handle])) {
-        if (!quiet) {
-            plain_error_message(_("Failed to find corresponding open process handle"));
-        }
-        return '';
-    }
-    $proc = $processes[$handle];
-
-
-    // get all we can from stdout, don't wait longer 
-    // than our timeout for input
-    //
-    $contents = '';
-    $read = array($proc[1][1]);
-    $write = NULL;
-    $except = NULL;
-    if (stream_select($read, $write, $except, $timeout_seconds))
-       while (!feof($proc[1][1])) $contents .= fread($proc[1][1], 8192);
-    return $contents;
-
-}
-}
-
-
-
-//
-// taken from functions/global.php on 2007/06/23
-// since 1.5.2
-//
-if (!function_exists('sq_pclose'))
-{
-function sq_pclose($handle, $quiet=TRUE) {
-
-    // yes, we are testing for proc_OPEN 
-    // because we need to know how the 
-    // handle was actually OPENED
-    //
-    if (!function_exists('proc_open'))
-        return pclose($handle);
-
-
-    // get our process out of the process store
-    //
-    global $processes;
-    if (!is_array($processes) || !isset($processes[$handle])) {
-        if (!quiet) {
-            plain_error_message(_("Failed to find corresponding open process handle"));
-        }
-        return 127;
-    }
-    $proc = $processes[$handle];
-    unset($processes[$handle]);
-
-
-    // close all pipes
-    //
-    fclose($proc[1][0]);
-    fclose($proc[1][1]);
-    fclose($proc[1][2]);
-
-
-    // close process
-    //
-    return proc_close($proc[0]);
-
-}
-}
-
-
-
 //
 // taken from functions/global.php on 2007/06/23
 // since 1.5.2
