@@ -170,17 +170,24 @@ fi
 echo
 read -p "Enter Version Number [$OLD_VERSION]: " VERSION
 if [ -z "$VERSION" ] ; then
-   VERSION=$OLD_FULL_VERSION;
+   VERSION=$OLD_VERSION;
+#   VERSION=$OLD_FULL_VERSION;
 fi
 PURE_VERSION=`echo "$VERSION" | sed 's/-.*//'`
 
+if [ ! -z "$REQ_SM_VERSION" ] ; then
+   FINAL_VERSION="$PURE_VERSION-$REQ_SM_VERSION"
+else
+   FINAL_VERSION="$PURE_VERSION"
+fi
+
 
 
 # remove tarball we are building if present
 #
 echo
-echo "Removing $PACKAGE-$VERSION.tar.gz"
-rm -f $PACKAGE-$VERSION.tar.gz
+echo "Removing $PACKAGE-$FINAL_VERSION.tar.gz"
+rm -f $PACKAGE-$FINAL_VERSION.tar.gz
 
 
 
@@ -202,42 +209,7 @@ fi
 #
 echo "Replacing version in version file"
 echo "$PRETTY_NAME" > version
-echo $VERSION >> version
-
-
-
-# NO LONGER USED....
-#
-## create temp working directory one level up
-##
-#WORKING_DIR="../.delete_me.$PACKAGE.temp.$$"
-#echo "Creating temporary working directory: $WORKING_DIR"
-#if [ -e "$WORKING_DIR" ] ; then
-#  rm -rf "$WORKING_DIR"
-#fi
-#mkdir "$WORKING_DIR"
-#
-#
-#
-## move config files out of directory
-##
-#J=0
-#while [ "$J" -lt ${#CONFIG_FILES[@]} ]; do
-#
-#   echo "Excluding ${CONFIG_FILES[$J]}"
-#   CONFIG_FILE_NAME=`echo "${CONFIG_FILES[$J]}" | sed s/.*\\\///`
-#   if test `echo "${CONFIG_FILES[$J]}" | grep -ce "/"` -gt 0; then
-#      CONFIG_FILE_PATH=`echo "${CONFIG_FILES[$J]}" | sed s/\\\/[^/]\\\+$//`
-#      mkdir -p "$WORKING_DIR/$CONFIG_FILE_PATH"
-#   else
-#      CONFIG_FILE_PATH=""
-#   fi
-#   
-#   echo "Moving ${CONFIG_FILES[$J]} to $WORKING_DIR/$CONFIG_FILE_PATH/$CONFIG_FILE_NAME"
-#   mv "${CONFIG_FILES[$J]}" "$WORKING_DIR/$CONFIG_FILE_PATH/$CONFIG_FILE_NAME"
-#
-#   J=`expr $J + 1`
-#done
+echo $PURE_VERSION >> version
 
 
 
@@ -252,49 +224,20 @@ while [ "$J" -lt ${#CONFIG_FILES[@]} ]; do
 
    J=`expr $J + 1`
 done
-TAR_COMMAND="$TAR_COMMAND -f $PACKAGE-$VERSION.tar.gz $PACKAGE"
+TAR_COMMAND="$TAR_COMMAND -f $PACKAGE-$FINAL_VERSION.tar.gz $PACKAGE"
 
 
 
 # make tarball
 #
-echo "Creating $PACKAGE-$VERSION.tar.gz"
+echo "Creating $PACKAGE-$FINAL_VERSION.tar.gz"
 cd ../
 $TAR_COMMAND
-mv $PACKAGE-$VERSION.tar.gz $PACKAGE
+mv $PACKAGE-$FINAL_VERSION.tar.gz $PACKAGE
 cd $PACKAGE
 
 
 
-# NO LONGER USED....
-#
-## moving config files back in place
-##
-#J=0
-#while [ "$J" -lt ${#CONFIG_FILES[@]} ]; do
-#
-#   echo "Moving ${CONFIG_FILES[$J]} back into place"
-#   CONFIG_FILE_NAME=`echo "${CONFIG_FILES[$J]}" | sed s/.*\\\///`
-#   if test `echo "${CONFIG_FILES[$J]}" | grep -ce "/"` -gt 0; then
-#      CONFIG_FILE_PATH=`echo "${CONFIG_FILES[$J]}" | sed s/\\\/[^/]\\\+$//`
-#      mkdir -p "$WORKING_DIR/$CONFIG_FILE_PATH"
-#   else
-#      CONFIG_FILE_PATH=""
-#   fi
-#
-#   mv "$WORKING_DIR/$CONFIG_FILE_PATH/$CONFIG_FILE_NAME" "${CONFIG_FILES[$J]}"
-#
-#   J=`expr $J + 1`
-#done
-#
-#
-#
-## delete temp working directory 
-##
-#echo "Removing temporary working directory: $WORKING_DIR"
-#rm -rf "$WORKING_DIR"
-
-
 echo 
 echo "Finished"
 echo
